# Welcome to Surfactant's documentation!

Surfactant provides a modular framework to gather file information and analyze dependencies for generating an SBOM.

```{eval-rst}
.. toctree::
   :maxdepth: 2
   :caption: Contents:
```

# Indices and tables

```{eval-rst}
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
```
